#
# spec file for package libteam
#
# Copyright (c) 2014 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#

%define libteam_major 5
%define libteam_name %mklibname team %{libteam_major}

%define libteamdctl_major 0
%define libteamdctl_name %mklibname teamdctl %{libteamdctl_major}

%define develname %mklibname -d team

Name:		libteam
Version:	1.26
Release:	%mkrel 1
Summary:	Utilities for controlling 802.1AX team network device
License:	LGPLv2+
Group:		System/Base
Url:		http://libteam.org/
Source0:	http://libteam.org/files/%{name}-%{version}.tar.gz
BuildRequires:	doxygen
BuildRequires:	swig
BuildRequires:	pkgconfig(python2)
BuildRequires:	pkgconfig(dbus-1)
BuildRequires:	pkgconfig(jansson)
BuildRequires:	pkgconfig(libdaemon)
BuildRequires:	pkgconfig(libnl-3.0) >= 3.2.0
BuildRequires:	pkgconfig(libnl-cli-3.0) >= 3.2.0
BuildRequires:	pkgconfig(libnl-genl-3.0) >= 3.2.0
BuildRequires:	pkgconfig(libnl-route-3.0) >= 3.2.0

%description
A library which is the user-space counterpart for the team network
driver, and provides an API to control them.

Linux kernel 3.3 and above offer a so-called "team" network driver -
a lightweight mechanism for bonding multiple interfaces together.
It is a userspace-driven alternative to the existing bonding driver.

%package -n %{libteam_name}
Summary:	Library for controlling 802.1AX team network device
Group:		System/Libraries
Obsoletes:	%{mklibname libteam 5} < 1.15-3

%description -n %{libteam_name}
A library which is the user-space counterpart for the team network
driver, and provides an API to control them.

Linux kernel 3.3 and above offer a so-called "team" network driver -
a lightweight mechanism for bonding multiple interfaces together.
It is a userspace-driven alternative to the existing bonding driver.

%package -n %{libteamdctl_name}
Summary:	Library for controlling the team network device daemon
Group:		System/Libraries
Obsoletes:	%{mklibname libteamdctl 0} < 1.15-3

%description -n %{libteamdctl_name}
Linux kernel 3.3 and above offer a so-called "team" network driver -
a lightweight mechanism for bonding multiple interfaces together.
It is a userspace-driven alternative to the existing bonding driver.

%package -n %{develname}
Summary:	Development files for libteam
Group:		Development/C
Provides:	%{name}-devel = %{version}-%{release}
Requires:	%{libteam_name} = %{version}
Requires:	%{libteamdctl_name} = %{version}

%description -n %{develname}
A library which is the user-space counterpart for the team network
driver, and provides an API to control them.

This package contains the development headers for the libteam and
libteamdctl libraries.

%package tools
Summary:	Utilities for controlling team network devices
Group:		System/Networking

%description tools
This package contains frontends to libteam that allow changing
the (team-specific) properties of team devices.
(The general configuration of network devices can be done
through using iproute.)

Linux kernel 3.3 and above offer a so-called "team" network driver -
a lightweight mechanism for bonding multiple interfaces together.
It is a userspace-driven alternative to the existing bonding driver.

%package -n python-libteam
Summary:	Python bindings for libteam
Group:		Development/Python

%description -n python-libteam
This package should be installed if you want to develop Python
programs that will manipulate team network devices.

%prep
%setup -q

%build
autoreconf -fi
%configure2_5x \
	--bindir=%{_sbindir} \
	--disable-static
%make_build

pushd binding/python/
%py2_build
popd

%install
%make_install

pushd binding/python/
%py2_install
popd

#systemd units
mkdir -p %{buildroot}%{_unitdir}
install -pm0644 teamd/redhat/systemd/*.service %{buildroot}%{_unitdir}/

#we don't want these
find %{buildroot} -name "*.la" -delete

%check
make check

%files -n %{libteam_name}
%{_libdir}/libteam.so.%{libteam_major}{,.*}

%files -n %{libteamdctl_name}
%{_libdir}/libteamdctl.so.%{libteamdctl_major}{,.*}

%files -n %{develname}
%{_includedir}/team.h
%{_includedir}/teamdctl.h
%{_libdir}/libteam.so
%{_libdir}/libteamdctl.so
%{_libdir}/pkgconfig/libteam.pc
%{_libdir}/pkgconfig/libteamdctl.pc

%files tools
%{_sbindir}/bond2team
%{_sbindir}/teamd
%{_sbindir}/teamdctl
%{_sbindir}/teamnl
%{_mandir}/man1/bond2team.1*
%{_mandir}/man5/teamd.conf.5*
%{_mandir}/man8/teamd.8*
%{_mandir}/man8/teamdctl.8*
%{_mandir}/man8/teamnl.8*
%{_unitdir}/teamd@.service

%files -n python-libteam
%{python2_sitearch}/*


%changelog
* Sun Feb 19 2017 wally <wally> 1.26-1.mga6
+ Revision: 1086941
- new version 1.26

* Tue May 10 2016 tv <tv> 1.24-1.mga6
+ Revision: 1012098
- new release

* Thu Apr 07 2016 daviddavid <daviddavid> 1.23-4.mga6
+ Revision: 999049
- really add proper obsoletes after the name change

* Wed Apr 06 2016 tv <tv> 1.23-3.mga6
+ Revision: 998964
- add proper obsoletes after the name change

* Fri Feb 12 2016 daviddavid <daviddavid> 1.23-2.mga6
+ Revision: 959097
- use new python macros

* Thu Feb 11 2016 luigiwalser <luigiwalser> 1.23-1.mga6
+ Revision: 955866
- 1.23 (fixes build issues)
- fix nonsense library subpackage names
- do not use strange includedir
- remove nonsense service macro usage on template services
- make files list more specific

  + umeabot <umeabot>
    - Mageia 6 Mass Rebuild

* Thu Feb 19 2015 ovitters <ovitters> 1.15-1.mga5
+ Revision: 815849
- import package originally based on opensuse spec

